﻿using System;
using System.IO;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Serialize;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Wpf;

namespace _8891
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            WpfMap map = (WpfMap)sender;
            LayerOverlay layerOverlay = GenerateImageOverlay(map, @"..\..\AppData\TC_NG_SFBay_US_Geo.tif");
            map.Overlays.Add(layerOverlay);

            //map.MapUnit = GeographyUnit.DecimalDegree;
            //map.CurrentExtent = new RectangleShape(-48.5286262681766, -6.18288677427336, -48.3432095970202, -6.4046923351998);

            //LayerOverlay layerOverlay = new LayerOverlay();

            //GeoTiffRasterLayer layer = new GeoTiffRasterLayer(@"..\..\AppData\TC_NG_SFBay_US_Geo.tif", map.CurrentExtent);                        
            //string path = @"..\..\AppData\test.xml";

            //GeoSerializer gs = new GeoSerializer();
            //gs.Serialize(layer, path); // serialize to xml

            //GeoTiffRasterLayer geoTiffRasterLayer = gs.Deserialize(File.ReadAllText(path)) as GeoTiffRasterLayer; // deserialize back
            //layerOverlay.Layers.Add(geoTiffRasterLayer);
            //map.Overlays.Add(layerOverlay);
            map.Refresh();
        }

        private void MapContainer_Loaded(object sender, RoutedEventArgs e)
        {           
        }

       
        public LayerOverlay GenerateImageOverlay(WpfMap mainMap, string filePath)
        {
            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.TileType = TileType.SingleTile;
           


            string worldFilePath = GetWorldFileName(filePath);

            GeoTiffRasterLayer tifLayer = null;
            if (File.Exists(worldFilePath))
            {
                tifLayer = new GeoTiffRasterLayer(filePath, worldFilePath);
            }
            else
            {
                tifLayer = new GeoTiffRasterLayer(filePath);
            }

          
            tifLayer.Name = System.IO.Path.GetFileNameWithoutExtension(filePath);

            tifLayer.Open();          

            if (tifLayer.HasBoundingBox)
            {
                mainMap.CurrentExtent = tifLayer.GetBoundingBox();
            }

            tifLayer.Close();
            layerOverlay.Layers.Add("ImportImage", tifLayer);
            return layerOverlay;
        }

        private static string GetWorldFileName(string fileName)
        {
            string extension = System.IO.Path.GetExtension(fileName);
            string newExtension = String.Concat(extension.Remove(extension.Length - 2, 1), 'w');
            return System.IO.Path.ChangeExtension(fileName, newExtension);
        }

        string path = @"..\..\AppData\test.xml";

        private void btnDeserialize_Click(object sender, RoutedEventArgs e)
        {
            WpfMap map = null;

            if (MapContainer.Children.Count > 0)
            {
                map = (WpfMap)MapContainer.Children[0];
            }

            GeoSerializer gs = new GeoSerializer();

            WpfMap mapFromFile = gs.Deserialize(File.ReadAllText(path)) as WpfMap;

            if (map != null)
            {
                map.Dispose();
                MapContainer.Children.Remove(map);
            }

            MapContainer.Children.Add(mapFromFile);
            
        }

        private void btnSerialize_Click(object sender, RoutedEventArgs e)
        {
            WpfMap map = (WpfMap)MapContainer.Children[0];

            GeoSerializer gs = new GeoSerializer();
            gs.Serialize(map, path); // serialize to xml

            //map.Dispose();
            //MapContainer.Children.Clear();
        }

        private void btnCreateMap_Click(object sender, RoutedEventArgs e)
        {
            WpfMap map = new WpfMap();

            map.MaximumScale = double.MaxValue;          

            MapContainer.Children.Add(map);

            map.Loaded += map_Loaded;
        }
    }
}
